import pandas as pd
from os import path

def get_stocks_with_weekly_options():
    """ Returns set of all stocks with weekly options"""
    weeklyOptions = pd.read_csv(path.join(path.abspath(path.dirname(__file__)), 'input_data','cboesymboldirweeklys.csv'))
    weeklyOptions.columns = ['name', 'symbol']
    weeklySet = set(weeklyOptions['symbol'])
    return weeklySet
    
def get_stocks_with_options():
    """ Returns set of all stocks with options"""
    indexOptions = pd.read_csv(path.join(path.abspath(path.dirname(__file__)), 'input_data','cboesymboldirequityindex.csv'))
    indexOptions.drop(columns = [' DPM Name', ' Post/Station'], inplace=True)
    indexOptions.columns = ['name', 'symbol']
    optionSet = set(indexOptions['symbol'])
    return optionSet


import pandas as pd
from datetime import date
import os
from earningstrats.earnings import *

def check_today(period = "5y", day_shift = 0, min_vol_sum = 3000, min_stock_price = 10):
    """
    Returns tuple of today AMC and tomorrow BMO companies' put option chain and historical earnings price effect
    Change days_added to shift day by that much. Customize minimum volume sum and stock price
    [0] - OTM Put option Chain
    [1] - Historical earnings price effect = Change period to change how far back historical price effect shows
    Outputs to today_companies.html, today_options.html, today_price_effect.html
    """
    today_comp = get_companies_with_earnings_today_AMC_or_tomm_BMO(day_shift, min_vol_sum, min_stock_price)
    total = pd.DataFrame()
    price = pd.DataFrame()
    
    yearPath = os.path.join(str(date.today().year))
    if not os.path.exists(yearPath):
        os.mkdir(yearPath)
        
    outdir = os.path.join(yearPath, str(date.today()))
    
    for row in today_comp.iterrows():
        ticker = row[1].ticker
        temp = get_put_option_chain(ticker)

        if not os.path.exists(outdir):
            os.mkdir(outdir)

        fullname = os.path.join(outdir, ticker + ".csv")    
        temp.to_csv(fullname)
        
        today_path = os.path.join(outdir, "companies.csv")    
        today_comp.to_csv(today_path)

        total = pd.concat([total, temp], ignore_index=True)
        total.loc["Empty"] = '' 
        total.loc["Space"] = ''        

        price_effect = get_stock_earnings_price_effect(ticker, period)
        price_effect.loc["Empty"] = '' 
        price_effect.loc["Space"] = '' 
        price = pd.concat([price, price_effect])   
    
    today_comp.to_html("today_companies.html")
    total.to_html('today_options.html')
    price.to_html('today_price_effect.html')
    return (total, price)


if __name__ == "__main__":
    check_today("5y", day_shift = 0, min_vol_sum = 1000, min_stock_price = 10)
    get_IV_crush_for_puts()    




from setuptools import setup, find_packages
from pathlib import Path
this_directory = Path(__file__).parent
long_description = (this_directory / "README.md").read_text()

setup(
    name='earningstrats',
    version = "0.1.2",
    description ='Use Stock Earnings Data to formulate strategies',
    long_description = long_description,
    long_description_content_type='text/markdown',
    url='https://github.com/woojuyim/earningstrats',
    download_url = 'https://github.com/woojuyim/earningstrats/archive/refs/tags/v0.1.1.tar.gz',
    author='Wooju Yim',
    author_email='woojuyim126@gmail.com',
    license='Apache License',
    classifiers=[
        'License :: OSI Approved :: Apache Software License',
        # 'Development Status :: 3 - Alpha',
        'Development Status :: 4 - Beta',
        # 'Development Status :: 5 - Production/Stable',


        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'Topic :: Office/Business :: Financial :: Investment',
        'Topic :: Scientific/Engineering :: Interface Engine/Protocol Translator',
        'Topic :: Software Development :: Libraries :: Python Modules',

        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: 3.10',
    ],
    platforms=['any'],
    keywords='pandas, yahoo finance, earnings, gamma, options',
    packages = find_packages(exclude=['contrib', 'docs', 'tests', 'examples']),
    install_requires=['numpy==1.22.4', 'pandas==1.4.2', 'scipy==1.8.1',
                      'yahoo_fin==0.8.9.1', 'yfinance==0.1.70'],
    entry_points={
        'console_scripts': [
            'sample = sample:main',
        ],
    },
    include_package_data=True,

)